@@ -1,8 +1,9 @@
 import inspect
-from unitgrade.unitgrade import methodsWithDecorator, hide
+from unitgrade.utils import hide, methodsWithDecorator
 import os
 import importlib
 
+
 def remove_hidden_methods(ReportClass, outfile=None):
     # Given a ReportClass, clean out all @hidden tests from the imports of that class.
     file = ReportClass()._file()
@@ -12,7 +13,6 @@ def remove_hidden_methods(ReportClass, outfile=None):
     lines_to_rem = []
 
     for Q,_ in ReportClass.questions:
-        print(Q)
         ls = list(methodsWithDecorator(Q, hide))
         print("hide decorateed is", ls)
         for f in ls:
@@ -31,13 +31,11 @@ def remove_hidden_methods(ReportClass, outfile=None):
     with open(outfile, 'w') as f:
         f.write(source)
 
-    mname = ReportClass.__module__
-    mname.find(".")
-    mname = mname[:mname.rfind(".")] + "." + os.path.basename(outfile)[:-3]
+    module_name = ReportClass.__module__
+    module_name.find(".")
+    module_name = module_name[:module_name.rfind(".")] + "." + os.path.basename(outfile)[:-3]
 
-    module = importlib.import_module(mname)
+    module = importlib.import_module(module_name)
 
     HiddenReportClass = getattr(module, ReportClass.__name__)
     return outfile, HiddenReportClass
-
-
