@@ -7,7 +7,6 @@ import io
 import subprocess
 import urllib.request
 
-
 def download_docker_images(destination=None):
     if destination is None:
         destination = os.getcwd()
@@ -32,8 +31,6 @@ def download_docker_images(destination=None):
             else:
                 print("> Extracting docker image", os.path.basename(f[:-1]), "to", dest)
                 shutil.copytree(tmp_dir, dest)
-        # zf.extract(f, path=destination)
-    a = 234
 
 
 def compile_docker_image(Dockerfile, tag=None):
@@ -47,9 +44,12 @@ def compile_docker_image(Dockerfile, tag=None):
 
 def student_token_file_runner(host_tmp_dir, student_token_file, instructor_grade_script, grade_file_relative_destination):
     """
-
+    This code is used to run student unitgrade tests (i.e., a .token file).
     Use by autolab code.
 
+    It accepts a student .token file which is extracted, the 'correct' instructor grade script is copied
+    into it, and it is then run.
+
     :param Dockerfile_location:
     :param host_tmp_dir:
     :param student_token_file:
@@ -59,47 +59,37 @@ def student_token_file_runner(host_tmp_dir, student_token_file, instructor_grade
     """
     assert os.path.exists(student_token_file)
     assert os.path.exists(instructor_grade_script)
-    start = time.time()
     from unitgrade_private import load_token
+    start = time.time()
     results, _ = load_token(student_token_file)
-    # with open(student_token_file, 'rb') as f:
-    #     results = pickle.load(f)
     sources = results['sources'][0]
-
     with io.BytesIO(sources['zipfile']) as zb:
         with zipfile.ZipFile(zb) as zip:
             zip.extractall(host_tmp_dir)
-    # Done extracting the zip file! Now time to move the (good) report test class into the location.
 
+    # Done extracting the zip file! Now time to move the (good) report test class into the location.
     gscript = instructor_grade_script
     print(f"{sources['report_relative_location']=}")
     print(f"{sources['name']=}")
-
     print("Now in docker_helpers.py")
     print(f'{gscript=}')
     print(f'{instructor_grade_script=}')
     gscript_destination = host_tmp_dir + "/" + grade_file_relative_destination
     print(f'{gscript_destination=}')
-
     shutil.copy(gscript, gscript_destination)
-
     # Now everything appears very close to being set up and ready to roll!.
     d = os.path.normpath(grade_file_relative_destination).split(os.sep)
     d = d[:-1] + [os.path.basename(instructor_grade_script)[:-3]]
     pycom = ".".join(d)
-
     """
     docker run -v c:/Users/tuhe/Documents/2021/python-docker/tmp:/app python-docker python3 -m cs202courseware.ug2report1_grade
     """
-    pycom = "python3 -m " + pycom # pycom[:-3]
+    pycom = "python3 -m " + pycom
     print(f"{pycom=}")
-
     token_location = host_tmp_dir + "/" + os.path.dirname( grade_file_relative_destination ) + "/*.token"
-
     elapsed = time.time() - start
     # print("Elapsed time is", elapsed)
-    return pycom, token_location
-
+    return pycom, host_tmp_dir, token_location
 
 
 def docker_run_token_file(Dockerfile_location, host_tmp_dir, student_token_file, tag=None, instructor_grade_script=None,
